@@ -60,7 +60,34 @@ class ReadTool:
         read_args: Optional[Union[LineArgs, RegexArgs]] = None
     ) -> Dict[str, Any]:
         """
-        Simplified file rseading with smart token management.
+        Read file content with smart token management and flexible reading modes.
+
+        USAGE MODES:
+        - Full read (no args): Small-medium files, initial exploration
+        - Line ranges (LineArgs): Specific sections, around error locations
+        - Regex search (RegexArgs): Find patterns, function definitions
+
+        WHEN TO USE:
+        - Always read before editing files for safety and context
+        - Code exploration and understanding structure
+        - Debugging specific sections or error locations
+        - Gathering context for modifications
+
+        LIMITATIONS:
+        - Large files (>50MB): Use line ranges to avoid token limits
+        - Binary files: Will fail with encoding errors
+        - Very long files: Content may be truncated with warning
+
+        BEST PRACTICES:
+        - Use line ranges for large files when you know target location
+        - Use regex for pattern searching: r'def function_name'
+        - Check 'success' field before processing content
+        - Read around error lines (±10-20 lines for context)
+
+        COMMON ERRORS:
+        - "File not found": Check path spelling and existence
+        - "Permission denied": File access restrictions
+        - "Content truncated": File too large, use targeted reading
 
         Args:
             file_path: Path to file to read
